==> visitors-8.x-2.16.tar.gz: visitors/src/Service/RebuildIpAddressService.php <==
<?php

namespace Drupal\visitors\Service;

use Drupal\Core\Database\Connection;
use Drupal\visitors\VisitorsRebuildIpAddressInterface;

/**
 * Convert legacy IP address to new format.
 */
class RebuildIpAddressService implements VisitorsRebuildIpAddressInterface {


  const ERROR = -1;

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * Constructs a new Rebuild Route Service.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection.
   */
  public function __construct(Connection $connection) {
    $this->database = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public function rebuild(string $ip_address): int {
    if (inet_pton($ip_address) !== FALSE) {
      return 0;
    }
    $new_address = NULL;
    if (ip2long($ip_address) !== FALSE) {
      $new_address = ip2long($ip_address);
    }
    elseif (inet_ntop($ip_address) !== FALSE) {
      $new_address = inet_ntop($ip_address);
    }
    else {
      return self::ERROR;
    }

    $count = self::ERROR;
    try {
      $count = $this->database->update('visitors')
        ->fields(['visitors_ip' => $new_address])
        ->condition('visitors_ip', $ip_address)
        ->execute();
    }
    catch (\Exception $e) {
      watchdog_exception('visitors', $e);
    }

    return $count;
  }

  /**
   * {@inheritdoc}
   */
  public function getIpAddresses(): array {
    $ip_addresses = $this->database->select('visitors', 'v')
      ->fields('v', [
        'visitors_ip',
      ])
      ->distinct()
      ->orderBy('visitors_ip', 'ASC')
      ->execute()->fetchAll();

    return $ip_addresses;
  }

}

==> visitors-8.x-2.20.tar.gz: visitors/src/Service/RebuildIpAddressService.php <==
<?php

namespace Drupal\visitors\Service;

use Drupal\Core\Database\Connection;
use Drupal\Core\Utility\Error;
use Drupal\visitors\VisitorsRebuildIpAddressInterface;
use Psr\Log\LoggerInterface;

/**
 * Convert legacy IP address to new format.
 */
class RebuildIpAddressService implements VisitorsRebuildIpAddressInterface {

  const ERROR = -1;

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * The logger.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * Constructs a new Rebuild Route Service.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection.
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger.
   */
  public function __construct(Connection $connection, LoggerInterface $logger) {
    $this->database = $connection;
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public function rebuild(string $ip_address): int {
    if (inet_pton($ip_address) !== FALSE) {
      return 0;
    }
    $new_address = NULL;
    if (ip2long($ip_address) !== FALSE) {
      $new_address = ip2long($ip_address);
    }
    elseif (inet_ntop($ip_address) !== FALSE) {
      $new_address = inet_ntop($ip_address);
    }
    else {
      return self::ERROR;
    }

    $count = self::ERROR;
    try {
      $count = $this->database->update('visitors')
        ->fields(['visitors_ip' => $new_address])
        ->condition('visitors_ip', $ip_address)
        ->execute();
    }
    catch (\Exception $e) {
      if (version_compare(\Drupal::VERSION, '10.1', '>=')) {
        Error::logException($this->logger, $e);
      }
      else {
        // @phpstan-ignore-next-line
        watchdog_exception('visitors', $e);
      }
    }

    return $count;
  }

  /**
   * {@inheritdoc}
   */
  public function getIpAddresses(): array {
    $ip_addresses = $this->database->select('visitors', 'v')
      ->fields('v', [
        'visitors_ip',
      ])
      ->distinct()
      ->orderBy('visitors_ip', 'ASC')
      ->execute()->fetchAll();

    return $ip_addresses;
  }

}
